<script src="https://cdn.bootcdn.net/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/gh/caibingcheng/orlike@master/orlike.js"></script>
<!-- <script src="orlike.js"></script> -->
<div class="orlike-box"></div>
<script>
    new OrLike({
        serverUrl: "{{ server }}",
        el: ".orlike-box",
        days: 30,
    });
</script>