<link href='https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.3/css/all.min.css' rel='stylesheet'>
<link rel='stylesheet' type='text/css' href='https://cdn.jsdelivr.net/gh/caibingcheng/orlike@master/orlike.min.css'>
<a class='likeit orlike' href='javascript:void(0)'>
    <i class='fa fa-thumbs-up'><span>0</span></i>
</a>
<a class='dislikeit orlike' href='javascript:void(0)'>
    <i class='fa fa-thumbs-down'><span>0</span></i>
</a>